﻿import QtQuick 2.2
import QtQuick.Controls 1.4
import QtQuick.Controls.Styles 1.4

Rectangle {
    id:comboBox

    onFocusChanged: {
        if (comboBox.focus === false)
            comboBox.state = "";
    }

    signal comboClicked;
    property Item displayItemText;

    Rectangle {
        id:displayItem
        anchors.fill: parent
        border.color: "#dbdbdb"
        border.width: 1
        radius: 3
        Text {
            id:displayItemText
            anchors.left: parent.left;
            anchors.leftMargin: 5;
            anchors.verticalCenter: parent.verticalCenter
            width: parent.width * 0.8;
            text:"默认组织"
            font.family: "微软雅黑"
            font.pointSize: 9;
            color: listView.currentIndex > -1 ? "#333333" : "#333333";//#999999
            elide: Text.ElideRight;
        }
        Image {
            id:image
            anchors.right: parent.right;
            anchors.rightMargin: 5;
            anchors.verticalCenter: parent.verticalCenter;
            source: "qrc:/resource/images/im/downarrow_combox.png"
        }
        MouseArea {
            anchors.fill: parent ;
            onClicked: {
                comboBox.state = comboBox.state==="dropDown"? "" : "dropDown"
                comboBox.focus = true;
                comboBox.comboClicked();
            }
            hoverEnabled:true;
        }
    }
    Rectangle {
        id:dropDown
        width:comboBox.width;
        height:150
        clip:true;
        color: "#FFFFFF"
        border.color: "#46b4aa"
        anchors.top: displayItem.bottom
        anchors.topMargin: 1
        visible: false
        ListModel {
            id: companymodel

        }
        ScrollView {
            anchors.fill: parent
            anchors.top: parent.top
            anchors.topMargin: 1
            anchors.left: parent.left
            anchors.leftMargin: 1
            anchors.right: parent.right
            anchors.rightMargin: 1
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 1
            style: ScrollViewStyle {
                handle: Item{
                    implicitWidth: 7
                    Rectangle {
                        color: "#B0B0B0"
                        anchors.fill: parent
                        visible: true
                        radius: 5
                    }
                }
                decrementControl:Image {
                    width:7
                    height: 7
                    source: "qrc:/resource/images/im/uparrow.png"
                }
                incrementControl:Image {
                    width: 7
                    height: 7
                    source: "qrc:/resource/images/im/downarrow.png"
                }
                scrollBarBackground: Rectangle {
                    implicitWidth: 7
                    color: "#EBF3F8"

                }
            }
            ListView {
                id:listView
                anchors.fill: parent
                model:companymodel
                currentIndex: 0
                delegate: Item{
                    height: comboBox.height;
                    anchors.left: parent.left
                    anchors.leftMargin: 1
                    anchors.right: parent.right
                    anchors.rightMargin: 1
                    property string strOid: ""
                    Rectangle {
                        id: mouseMoveHighLight
                        width:listView.width -2;
                        height:comboBox.height;
                        anchors.top: parent.top
                        anchors.topMargin: 1
                        color: "#FFFFFF";
                    }
                    Text {
                        width: parent.width * 0.9;
                        text: name
                        font.family: "微软雅黑"
                        color:"#333333"
                        anchors.verticalCenter: parent.verticalCenter;
                        anchors.left: parent.left;
                        anchors.leftMargin: 5
                        font.pointSize: 9
                        elide: Text.ElideRight;
                    }
                    MouseArea {

                        anchors.fill: parent;
                        hoverEnabled: true
                        onClicked: {
                            comboBox.state = ""
                           // listView.currentIndex = index;
                            var preSelection = displayItemText.text
                            displayItemText.text = companymodel.get(index).name
                            console.log(companymodel.get(index).name, companymodel.get(index).strOid)
                            if(displayItemText.text != preSelection){
                                //comboBox.comboClicked();
                            }
                            listView.currentIndex = index;
                        }
                        onEntered:{
                            mouseMoveHighLight.color = "#EEEEEE"
                        }

                        onExited: {
                            mouseMoveHighLight.color = "#FFFFFF"
                        }
                    }
                }
            }
        }
    }
    states: State {
        name: "dropDown";
        PropertyChanges { target: dropDown; visible:true}
    }


    function appendData(companyName, companyOid)
    {
        companymodel.append({"name": companyName, "strOid": companyOid})
    }
    function setComboxdisplayItemText(companyName)
    {
        displayItemText.text = companyName;
    }
    function getComboxdisplayItemText()
    {
     return   displayItemText.text;
    }

    function reMoveAllData()
    {
        companymodel.clear();
        displayItemText.text = "默认组织";
    }

    function modelCount()
    {
        return companymodel.count;
    }

    function modelIndexValue(index)
    {
        return companymodel.get(index).strOid;
    }

    function setCurrentIndex(index)
    {
        displayItemText.text = companymodel.get(index).name
        listView.currentIndex = index;
    }

    function getCurrentCompanyName()
    {
        if(companymodel.count == 0)
        {
            return "";
        }

        return companymodel.get(listView.currentIndex).name;
    }

    function getCurrentCompanyOid()
    {
        if(companymodel.count == 0)
        {
            return "";
        }
        return companymodel.get(listView.currentIndex).strOid;
    }
}
