﻿import QtQuick 2.7
import QtQuick.Window 2.2
import QtQuick.Controls 1.4
import QtQuick.Controls.Styles 1.4
import "../common"

Window {
    id: messagewindow
    width: 270
    height: 190
    flags: Qt.Window | Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint
    modality: Qt.ApplicationModal
    x: (Screen.desktopAvailableWidth - 270)/2
    y: (Screen.desktopAvailableHeight - 190)/2
    opacity: 1.0
    visible: true
    title:"提示"
    property alias messageText: context.text
    property string pageId: ""
    property bool bPressed: true
    property bool isSure : false

    signal deleteitem();
    signal sigSure(string id);
    signal sigCancel();

    MouseArea { //为窗口添加鼠标事件
        id:mouse
        anchors.fill: parent
        acceptedButtons: Qt.LeftButton //只处理鼠标左键
        property point clickPos: "0,0"
        onPressed: { //接收鼠标按下事件
            clickPos  = Qt.point(mouse.x,mouse.y)
            bPressed = true
        }

        onReleased: {
            bPressed = false;
        }

        onPositionChanged: { //鼠标按下后改变位置
            //鼠标偏移量
            if(bPressed)
            {
                var delta = Qt.point(mouse.x-clickPos.x, mouse.y-clickPos.y)
                //如果mainwindow继承自QWidget,用setPos
                messagewindow.setX(messagewindow.x+delta.x)
                messagewindow.setY(messagewindow.y+delta.y)
            }
        }
    }

    Rectangle{
        id: bkg
        anchors.fill: parent
        border.color: "#ccc"
        border.width: 1
        Rectangle {
            id: bkgimg
            anchors.top: parent.top
            anchors.left: parent.left
            width: parent.width
            height: 28
            color: "#168ADA"

            Image {
                id: titleicon
                anchors.top: parent.top
                anchors.topMargin: 7
                anchors.left:parent.left
                anchors.leftMargin: 6
                source: "qrc:/resource/images/main/common/info.png"
            }

            Text {
                id: titletext
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left:titleicon.right
                anchors.leftMargin: 3
                font.pixelSize: 12
                font.bold: false
                font.family: "微软雅黑"
                color: "#FFFFFF"
                text: qsTr("提示")
            }

            ControlButton {
                id: close
                anchors.top: parent.top
                anchors.topMargin: 0
                anchors.right: parent.right
                width: 28
                height: 28
                normalImage: "qrc:/resource/images/main/maintop/close.png"
                hoverImage: "qrc:/resource/images/main/maintop/closeHover.png"
                onClicked:{
                    messagewindow.deleteitem();
                }
            }
        }


        Image {
            id: icon
            anchors.left: parent.left
            anchors.leftMargin: 40
            anchors.top: bkgimg.bottom
            anchors.topMargin: 40
            width: 34
            height: 30
            source: "qrc:/resource/images/main/common/hint.png"

        }

        Text {
            id: context
            height: 20
            anchors.left: icon.right
            anchors.leftMargin: 15
            anchors.top: bkgimg.bottom
            anchors.topMargin: 45
            font.pixelSize: 16
            font.family: "微软雅黑"
            color: "#666666"
        }

        Rectangle{
            id: line
            anchors.bottom: surebtn.top
            anchors.bottomMargin: 15
            anchors.left: parent.left
            anchors.right: parent.right
            color: "#eeeeee"
            height: 1
            visible: false
        }

        Button {
            id: surebtn
            width: 60
            height: 24
            anchors.right: cancelbtn.left
            anchors.rightMargin: 16
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            visible: if(isSure)
                     {
                         return false;
                     }
                     else
                     {
                         return true ;
                     }

            style:ButtonStyle {
                background: Rectangle {
                    border.color: control.hovered ? "#0075c4" : "#ccc"
                    border.width: 1
                    radius: 3
                    color: control.hovered ? "#278ADD" : "#EEEEEE"
                }

                label: Text{
                    text:qsTr("确认")
                    font.pixelSize: 12
                    font.family: "微软雅黑"
                    color: control.hovered ? "#FFFFFF" : "#333333"
                    horizontalAlignment: Qt.AlignHCenter
                    verticalAlignment: Qt.AlignVCenter
                }
            }

            onClicked: {
                sigSure(pageId)
            }
        }

        Button {
            id: cancelbtn
            width: 60
            height: 24
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 15
            style:ButtonStyle {
                background: Rectangle {
                    border.color: control.hovered ? "#0075c4" : "#ccc"
                    border.width: 1
                    radius: 3
                    color: control.hovered ? "#278ADD" : "#EEEEEE"

                }

                label: Text{
                    text:if(isSure)
                         {
                             return qsTr("确认");
                         }
                         else
                         {
                             return qsTr("取消") ;
                         }


                    font.pixelSize: 12
                    font.family: "微软雅黑"
                    color:  control.hovered ?"#FFFFFF" :"#333333"
                    font.bold: false
                    horizontalAlignment: Qt.AlignHCenter
                    verticalAlignment: Qt.AlignVCenter
                }
            }

            onClicked: {
                sigCancel()
            }
        }
    }
}
