import QtQuick 2.2
import QtQuick.Controls 1.2
import QtQuick.Window 2.2

import "../common"

Window {

    //focus: true
    id: settingwindow
    visible: false
    width: 650
    height: 520
    property bool bPressed: true
    x: (Screen.desktopAvailableWidth - 650)/2
    y: (Screen.desktopAvailableHeight - 480)/2

    flags: Qt.Window | Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint
    modality: Qt.ApplicationModal

    signal saveLoginClicked(string passwd)
    signal deleteitem()

    function setVisible(viewid) {
        if(viewid === 0)      //登录设置界面
        {
            loginsettingview.visible = true

            selfdomsettingview.visible = false
            advancedsettingview.visible = false
        }
        else if(viewid === 1) //个性设置界面
        {
            loginsettingview.visible = false

            selfdomsettingview.visible = true
            //selfdomsettingview.selfdomView_setopenwebmode()
            advancedsettingview.visible = false
        }
        else if(viewid === 2) //高级设置界面
        {
            loginsettingview.visible = false
            selfdomsettingview.visible = false
            advancedsettingview.visible = true
        }
    }

    function setValue() {
        loginsettingview.setValue();
    }

    function translate()
    {
        loginsettingbtn.textContent = qsTr("登录设置")
        selfdomsettingbtn.textContent = qsTr("个性设置")
        advancedsettingbtn.textContent = qsTr("高级设置")
    }

    MouseArea { //为窗口添加鼠标事件
        id:mouse
        anchors.fill: parent
        acceptedButtons: Qt.LeftButton //只处理鼠标左键
        property point clickPos: "0,0"
        onPressed: { //接收鼠标按下事件
            clickPos  = Qt.point(mouse.x,mouse.y)
            bPressed = true
        }

        onReleased: {
            bPressed = false;
        }

        onPositionChanged: { //鼠标按下后改变位置
            //鼠标偏移量
            if(bPressed)
            {
                var delta = Qt.point(mouse.x-clickPos.x, mouse.y-clickPos.y)

                //如果mainwindow继承自QWidget,用setPos
                settingwindow.setX(settingwindow.x+delta.x)
                settingwindow.setY(settingwindow.y+delta.y)
            }
        }
    }
    Rectangle{
        anchors.fill: parent
        border.color: "#278ADD"
        border.width: 1

        Rectangle {
            id:settingTitle
            width: settingwindow.width
            height: 28
            anchors.top: parent.top
            anchors.right: parent.right
            color: "#278ADD"

            Image {
                id: icon
                width: 18
                height: 18
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 6
                source: "qrc:/resource/images/login/set1.png"
            }

            Text
            {
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: icon.right
                anchors.leftMargin: 3

                font.pixelSize: 12
                color: "white"
                font.family: "微软雅黑"
                verticalAlignment: Qt.AlignVCenter
                text: qsTr("OA办公精灵设置")
            }

            ControlButton {
                id:min
                anchors.top: parent.top
                anchors.topMargin:0
                anchors.right: close.left
                width: 28
                height: 28
                normalImage: "qrc:/resource/images/main/maintop/min.png"
                hoverImage: "qrc:/resource/images/main/maintop/minHover.png"
                onClicked: {
                    settingwindow.visibility = Window.Minimized
                   // creatNetObj()
                }
            }

            ControlButton{
                id:close
                anchors.top: parent.top
                anchors.topMargin: 0
                anchors.right: parent.right
                anchors.rightMargin: 0
                width: 28
                height: 28
                normalImage: "qrc:/resource/images/main/maintop/close.png"
                hoverImage: "qrc:/resource/images/main/maintop/closeHover.png"
                onClicked:{
                    settingwindow.deleteitem()
                }
            }
        }

        Rectangle {
            id: menulist
            width: 150
            anchors.top: settingTitle.bottom
            anchors.left: parent.left
            anchors.leftMargin: 1
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 1
            color: "#EEEEEE"

            ExclusiveGroup {
                id: exclusive
            }
            Text{
                width: 20
                height: 40
                anchors.bottom: parent.bottom
                anchors.bottomMargin:-15
                anchors.left: parent.left
                anchors.leftMargin:18
                color: "#1874CD"
                font.pixelSize: 12
                font.family: "微软雅黑"
                text: qsTr("版本号:"+fileio.readIniFile("def", "autologinMode"))
        }

            CheckedButton {
                id: loginsettingbtn
                width: menulist.width
                height: 40
                anchors.top: parent.top
                anchors.left: parent.left
                checkable: true
                checked: true
                normalcolor: "#EEEEEE"
                checkedcolor: "#FFFFFF"
                exclusiveGroup: exclusive
                textContent: qsTr("    网络和登录")
                iconSources: "qrc:/resource/images/login/loginset.png"
                onClicked: {
                    setVisible(0)
                }

            }

            CheckedButton {
                id: selfdomsettingbtn
                width: menulist.width
                height: 45
                anchors.top: loginsettingbtn.bottom
                anchors.left: parent.left
                normalcolor: "#EEEEEE"
                checkedcolor: "#FFFFFF"
                checkable: true
                exclusiveGroup: exclusive
                textContent: qsTr("个性设置")

                iconSources: "qrc:/resource/images/login/persionset.png"
                visible: true
                onClicked: {
                    setVisible(1)
                    //loginsettingbtn.visible=false

                }


            }

            CheckedButton {
                id: advancedsettingbtn
                width: menulist.width
                height: 45
                anchors.top: selfdomsettingbtn.bottom
                anchors.left: parent.left
                checkable: true
                normalcolor: "#EEEEEE"
                checkedcolor: "#FFFFFF"
                exclusiveGroup: exclusive
                visible: false
                textContent: qsTr("高级设置")
                onClicked: {
                    setVisible(2)
                }
            }
        }


        LoginSetting {
            id: loginsettingview
            anchors.top: settingTitle.bottom
            anchors.left: menulist.right
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            visible: true
            onSaveLoginClicked: {
                settingwindow.saveLoginClicked(passwd);
                settingwindow.deleteitem();
            }
            onCloseLoginClicked: {
                settingwindow.deleteitem();
            }
        }

        SelfdomSetting {
            id: selfdomsettingview
            anchors.top: settingTitle.bottom
            anchors.left: menulist.right
            anchors.bottom: parent.bottom
            anchors.right: parent.right
            visible: false
        }

        AdvancedSetting {
            id: advancedsettingview
            anchors.top: settingTitle.bottom
            anchors.left: menulist.right
            anchors.bottom: parent.bottom
            anchors.right: parent.right
            visible: false
        }
    }

}

